@@ -1,17 +1,21 @@
+'''Test for WFS calls'''
+
 from datetime import datetime
+import unittest
+import textwrap
 
 from numpy import nan
-from geoengine.types import QueryRectangle
-import unittest
-import geoengine as ge
 import requests_mock
 import geopandas as gpd
+import geopandas.testing  # pylint: disable=unused-import
 from shapely.geometry import Point
-import geopandas.testing
-import textwrap
+
+from geoengine.types import QueryRectangle
+import geoengine as ge
 
 
 class WfsTests(unittest.TestCase):
+    '''WFS test runner'''
 
     def setUp(self) -> None:
         ge.reset()
@@ -260,10 +264,14 @@ class WfsTests(unittest.TestCase):
 
             wfs_request = m.request_history[2]
             self.assertEqual(wfs_request.method, "GET")
-            self.assertEqual(wfs_request.url,
-                             "http://mock-instance/wfs?service=WFS&version=2.0.0&request=GetFeature&outputFormat=application%2Fjson&typeNames=registry%3A956d3656-2d14-5951-96a0-f962b92371cd&bbox=-60.0%2C5.0%2C61.0%2C6.0&time=2014-04-01T12%3A00%3A00.000%2B00%3A00&srsName=EPSG%3A4326&queryResolution=0.1%2C0.1")
+            self.assertEqual(
+                # pylint: disable=line-too-long
+                wfs_request.url,
+                "http://mock-instance/wfs?service=WFS&version=2.0.0&request=GetFeature&outputFormat=application%2Fjson&typeNames=registry%3A956d3656-2d14-5951-96a0-f962b92371cd&bbox=-60.0%2C5.0%2C61.0%2C6.0&time=2014-04-01T12%3A00%3A00.000%2B00%3A00&srsName=EPSG%3A4326&queryResolution=0.1%2C0.1"
+            )
 
             expected_df = gpd.GeoDataFrame(
+                # pylint: disable=line-too-long
                 {
                     "scalerank": [7, 7, 6, 5, 5, 5, 3],
                     "website": ["www.ghanaports.gov.gh", "www.nationalportauthorityliberia.org", None, "www.paa-ci.org", None, None, "www.paa-ci.org"],
